==> haskell-chell-quickcheck-0.2.5.1-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell-quickcheck
version: 0.2.5.1
id: chell-quickcheck-0.2.5.1-2muVCfxoGIrCPFPxt9NehG
key: chell-quickcheck-0.2.5.1-2muVCfxoGIrCPFPxt9NehG
license: MIT
maintainer: John Millikin <john@john-millikin.com>
author: John Millikin <john@john-millikin.com>
homepage: https://john-millikin.com/software/chell/
synopsis: QuickCheck support for the Chell testing library
category: Testing
abi: 01b9d0dd64e04efb85b71a264ca8db16
exposed: True
exposed-modules:
    Test.Chell.QuickCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/chell-quickcheck-0.2.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/chell-quickcheck-0.2.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/chell-quickcheck-0.2.5.1
hs-libraries: HSchell-quickcheck-0.2.5.1-2muVCfxoGIrCPFPxt9NehG
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    chell-0.4.0.2-5ENpvyUMfQzLCMhdmH9KuN
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             chell-0.4.0.2-5ENpvyUMfQzLCMhdmH9KuN=fc2c9743a6e7c7cc923bd45ddbb1c2e0
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
haddock-interfaces: /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-chell-quickcheck-0.2.5.1-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-chell-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: chell-quickcheck
version: 0.2.5.1
id: chell-quickcheck-0.2.5.1-Cdvr6webBDa4mOIOiOGr7A
key: chell-quickcheck-0.2.5.1-Cdvr6webBDa4mOIOiOGr7A
license: MIT
maintainer: John Millikin <john@john-millikin.com>
author: John Millikin <john@john-millikin.com>
homepage: https://john-millikin.com/software/chell/
synopsis: QuickCheck support for the Chell testing library
category: Testing
abi: 3b8a03501515e53208f12b406a3510bc
exposed: True
exposed-modules:
    Test.Chell.QuickCheck
import-dirs: /usr/lib/ghc-8.4.3/site-local/chell-quickcheck-0.2.5.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/chell-quickcheck-0.2.5.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/chell-quickcheck-0.2.5.1
hs-libraries: HSchell-quickcheck-0.2.5.1-Cdvr6webBDa4mOIOiOGr7A
depends:
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr base-4.11.1.0
    chell-0.4.0.2-JzCT77nUdLACEsLVzXugJ
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
abi-depends: QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             chell-0.4.0.2-JzCT77nUdLACEsLVzXugJ=7ce2aa7dc15e099fa6d3f302d996947d
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
haddock-interfaces: /usr/share/doc/haskell-chell-quickcheck/html/chell-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-chell-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
